@@ -17,7 +17,7 @@ import os.path
 from optparse import Option, OptionParser
 
 from commandor.exceptions import InvalidCommand
-from commandor.colors import blue
+from commandor.colors import blue, red
 from commandor.utils import indent, parse_args
 
 
@@ -51,6 +51,9 @@ class Mixin(object):
         """
         print(s)
 
+    def error(self, s):
+        self.display(red(s))
+
     def abort(self, s):
         """Display and exit
         """
@@ -108,7 +111,7 @@ class Commandor(Mixin):
                               default=False,
                               help='Show commands')]
 
-    def __init__(self, parser, args=[], options=[]):
+    def __init__(self, parser, args=sys.argv[1:], options=[]):
         """Initialize commandor
 
         :param parser: :class:`~optparse.OptionParse` object
@@ -116,7 +119,7 @@ class Commandor(Mixin):
         :param options: list of additional :class:`~optparse.Option` objects
         """
         self.parser = parser
-        self._args = args or sys.argv[1:]
+        self._args = args
         self._options = options
         self._curdir = None
 
